# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class OnlinePointConfigInputOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'point_code': 'str',
        'point_name': 'str',
        'position': 'str',
        'station_code': 'str',
        'unit': 'str',
        'is_key_point': 'bool',
        'is_input': 'bool',
        'is_use': 'bool',
        'default_value': 'float'
    }

    attribute_map = {
        'point_code': 'pointCode',
        'point_name': 'pointName',
        'position': 'position',
        'station_code': 'stationCode',
        'unit': 'unit',
        'is_key_point': 'isKeyPoint',
        'is_input': 'isInput',
        'is_use': 'isUse',
        'default_value': 'defaultValue'
    }

    def __init__(self, point_code=None, point_name=None, position=None, station_code=None, unit=None, is_key_point=None, is_input=None, is_use=None, default_value=None, local_vars_configuration=None):  # noqa: E501
        """OnlinePointConfigInputOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._point_code = None
        self._point_name = None
        self._position = None
        self._station_code = None
        self._unit = None
        self._is_key_point = None
        self._is_input = None
        self._is_use = None
        self._default_value = None
        self.discriminator = None

        self.point_code = point_code
        self.point_name = point_name
        self.position = position
        self.station_code = station_code
        self.unit = unit
        if is_key_point is not None:
            self.is_key_point = is_key_point
        if is_input is not None:
            self.is_input = is_input
        if is_use is not None:
            self.is_use = is_use
        if default_value is not None:
            self.default_value = default_value

    @property
    def point_code(self):
        """Gets the point_code of this OnlinePointConfigInputOutput.  # noqa: E501

        点位编码  # noqa: E501

        :return: The point_code of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_code

    @point_code.setter
    def point_code(self, point_code):
        """Sets the point_code of this OnlinePointConfigInputOutput.

        点位编码  # noqa: E501

        :param point_code: The point_code of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._point_code = point_code

    @property
    def point_name(self):
        """Gets the point_name of this OnlinePointConfigInputOutput.  # noqa: E501

        点位名称  # noqa: E501

        :return: The point_name of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_name

    @point_name.setter
    def point_name(self, point_name):
        """Sets the point_name of this OnlinePointConfigInputOutput.

        点位名称  # noqa: E501

        :param point_name: The point_name of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._point_name = point_name

    @property
    def position(self):
        """Gets the position of this OnlinePointConfigInputOutput.  # noqa: E501

        位置  # noqa: E501

        :return: The position of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this OnlinePointConfigInputOutput.

        位置  # noqa: E501

        :param position: The position of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._position = position

    @property
    def station_code(self):
        """Gets the station_code of this OnlinePointConfigInputOutput.  # noqa: E501

        站点编码  # noqa: E501

        :return: The station_code of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._station_code

    @station_code.setter
    def station_code(self, station_code):
        """Sets the station_code of this OnlinePointConfigInputOutput.

        站点编码  # noqa: E501

        :param station_code: The station_code of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._station_code = station_code

    @property
    def unit(self):
        """Gets the unit of this OnlinePointConfigInputOutput.  # noqa: E501

        单位  # noqa: E501

        :return: The unit of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this OnlinePointConfigInputOutput.

        单位  # noqa: E501

        :param unit: The unit of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def is_key_point(self):
        """Gets the is_key_point of this OnlinePointConfigInputOutput.  # noqa: E501

        是否为关键点位  # noqa: E501

        :return: The is_key_point of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_key_point

    @is_key_point.setter
    def is_key_point(self, is_key_point):
        """Sets the is_key_point of this OnlinePointConfigInputOutput.

        是否为关键点位  # noqa: E501

        :param is_key_point: The is_key_point of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: bool
        """

        self._is_key_point = is_key_point

    @property
    def is_input(self):
        """Gets the is_input of this OnlinePointConfigInputOutput.  # noqa: E501

        是否是输入数据  # noqa: E501

        :return: The is_input of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_input

    @is_input.setter
    def is_input(self, is_input):
        """Sets the is_input of this OnlinePointConfigInputOutput.

        是否是输入数据  # noqa: E501

        :param is_input: The is_input of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: bool
        """

        self._is_input = is_input

    @property
    def is_use(self):
        """Gets the is_use of this OnlinePointConfigInputOutput.  # noqa: E501

        是否启用该点位  # noqa: E501

        :return: The is_use of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_use

    @is_use.setter
    def is_use(self, is_use):
        """Sets the is_use of this OnlinePointConfigInputOutput.

        是否启用该点位  # noqa: E501

        :param is_use: The is_use of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: bool
        """

        self._is_use = is_use

    @property
    def default_value(self):
        """Gets the default_value of this OnlinePointConfigInputOutput.  # noqa: E501

        默认值  # noqa: E501

        :return: The default_value of this OnlinePointConfigInputOutput.  # noqa: E501
        :rtype: float
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this OnlinePointConfigInputOutput.

        默认值  # noqa: E501

        :param default_value: The default_value of this OnlinePointConfigInputOutput.  # noqa: E501
        :type: float
        """

        self._default_value = default_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OnlinePointConfigInputOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OnlinePointConfigInputOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class WeirAdjustmentParameter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device_code': 'str',
        'weir_adjustment_factor': 'float',
        'weir_adjustment_height': 'float',
        'weir_adjustment_opening': 'float',
        'adjust_minimum_amount': 'float',
        'minimum_opening': 'float',
        'maximum_opening': 'float',
        'sort': 'int'
    }

    attribute_map = {
        'device_code': 'deviceCode',
        'weir_adjustment_factor': 'weirAdjustmentFactor',
        'weir_adjustment_height': 'weirAdjustmentHeight',
        'weir_adjustment_opening': 'weirAdjustmentOpening',
        'adjust_minimum_amount': 'adjustMinimumAmount',
        'minimum_opening': 'minimumOpening',
        'maximum_opening': 'maximumOpening',
        'sort': 'sort'
    }

    def __init__(self, device_code=None, weir_adjustment_factor=None, weir_adjustment_height=None, weir_adjustment_opening=None, adjust_minimum_amount=None, minimum_opening=None, maximum_opening=None, sort=None, local_vars_configuration=None):  # noqa: E501
        """WeirAdjustmentParameter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._device_code = None
        self._weir_adjustment_factor = None
        self._weir_adjustment_height = None
        self._weir_adjustment_opening = None
        self._adjust_minimum_amount = None
        self._minimum_opening = None
        self._maximum_opening = None
        self._sort = None
        self.discriminator = None

        self.device_code = device_code
        if weir_adjustment_factor is not None:
            self.weir_adjustment_factor = weir_adjustment_factor
        if weir_adjustment_height is not None:
            self.weir_adjustment_height = weir_adjustment_height
        if weir_adjustment_opening is not None:
            self.weir_adjustment_opening = weir_adjustment_opening
        if adjust_minimum_amount is not None:
            self.adjust_minimum_amount = adjust_minimum_amount
        if minimum_opening is not None:
            self.minimum_opening = minimum_opening
        if maximum_opening is not None:
            self.maximum_opening = maximum_opening
        if sort is not None:
            self.sort = sort

    @property
    def device_code(self):
        """Gets the device_code of this WeirAdjustmentParameter.  # noqa: E501


        :return: The device_code of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: str
        """
        return self._device_code

    @device_code.setter
    def device_code(self, device_code):
        """Sets the device_code of this WeirAdjustmentParameter.


        :param device_code: The device_code of this WeirAdjustmentParameter.  # noqa: E501
        :type: str
        """

        self._device_code = device_code

    @property
    def weir_adjustment_factor(self):
        """Gets the weir_adjustment_factor of this WeirAdjustmentParameter.  # noqa: E501

        堰调整系数  # noqa: E501

        :return: The weir_adjustment_factor of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: float
        """
        return self._weir_adjustment_factor

    @weir_adjustment_factor.setter
    def weir_adjustment_factor(self, weir_adjustment_factor):
        """Sets the weir_adjustment_factor of this WeirAdjustmentParameter.

        堰调整系数  # noqa: E501

        :param weir_adjustment_factor: The weir_adjustment_factor of this WeirAdjustmentParameter.  # noqa: E501
        :type: float
        """

        self._weir_adjustment_factor = weir_adjustment_factor

    @property
    def weir_adjustment_height(self):
        """Gets the weir_adjustment_height of this WeirAdjustmentParameter.  # noqa: E501

        单位变化堰调整开度  # noqa: E501

        :return: The weir_adjustment_height of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: float
        """
        return self._weir_adjustment_height

    @weir_adjustment_height.setter
    def weir_adjustment_height(self, weir_adjustment_height):
        """Sets the weir_adjustment_height of this WeirAdjustmentParameter.

        单位变化堰调整开度  # noqa: E501

        :param weir_adjustment_height: The weir_adjustment_height of this WeirAdjustmentParameter.  # noqa: E501
        :type: float
        """

        self._weir_adjustment_height = weir_adjustment_height

    @property
    def weir_adjustment_opening(self):
        """Gets the weir_adjustment_opening of this WeirAdjustmentParameter.  # noqa: E501

        单位变化堰调整开度  # noqa: E501

        :return: The weir_adjustment_opening of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: float
        """
        return self._weir_adjustment_opening

    @weir_adjustment_opening.setter
    def weir_adjustment_opening(self, weir_adjustment_opening):
        """Sets the weir_adjustment_opening of this WeirAdjustmentParameter.

        单位变化堰调整开度  # noqa: E501

        :param weir_adjustment_opening: The weir_adjustment_opening of this WeirAdjustmentParameter.  # noqa: E501
        :type: float
        """

        self._weir_adjustment_opening = weir_adjustment_opening

    @property
    def adjust_minimum_amount(self):
        """Gets the adjust_minimum_amount of this WeirAdjustmentParameter.  # noqa: E501

        调节最小量  # noqa: E501

        :return: The adjust_minimum_amount of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: float
        """
        return self._adjust_minimum_amount

    @adjust_minimum_amount.setter
    def adjust_minimum_amount(self, adjust_minimum_amount):
        """Sets the adjust_minimum_amount of this WeirAdjustmentParameter.

        调节最小量  # noqa: E501

        :param adjust_minimum_amount: The adjust_minimum_amount of this WeirAdjustmentParameter.  # noqa: E501
        :type: float
        """

        self._adjust_minimum_amount = adjust_minimum_amount

    @property
    def minimum_opening(self):
        """Gets the minimum_opening of this WeirAdjustmentParameter.  # noqa: E501

        最小开度  # noqa: E501

        :return: The minimum_opening of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: float
        """
        return self._minimum_opening

    @minimum_opening.setter
    def minimum_opening(self, minimum_opening):
        """Sets the minimum_opening of this WeirAdjustmentParameter.

        最小开度  # noqa: E501

        :param minimum_opening: The minimum_opening of this WeirAdjustmentParameter.  # noqa: E501
        :type: float
        """

        self._minimum_opening = minimum_opening

    @property
    def maximum_opening(self):
        """Gets the maximum_opening of this WeirAdjustmentParameter.  # noqa: E501

        最大开度  # noqa: E501

        :return: The maximum_opening of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: float
        """
        return self._maximum_opening

    @maximum_opening.setter
    def maximum_opening(self, maximum_opening):
        """Sets the maximum_opening of this WeirAdjustmentParameter.

        最大开度  # noqa: E501

        :param maximum_opening: The maximum_opening of this WeirAdjustmentParameter.  # noqa: E501
        :type: float
        """

        self._maximum_opening = maximum_opening

    @property
    def sort(self):
        """Gets the sort of this WeirAdjustmentParameter.  # noqa: E501


        :return: The sort of this WeirAdjustmentParameter.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this WeirAdjustmentParameter.


        :param sort: The sort of this WeirAdjustmentParameter.  # noqa: E501
        :type: int
        """

        self._sort = sort

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WeirAdjustmentParameter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WeirAdjustmentParameter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class ControlRuleInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cs_pumps': 'list[CsPump]',
        'cs_valves': 'list[CsValve]',
        'river_pumps': 'list[RiverPump]',
        'river_gates': 'list[RiverGate]'
    }

    attribute_map = {
        'cs_pumps': 'csPumps',
        'cs_valves': 'csValves',
        'river_pumps': 'riverPumps',
        'river_gates': 'riverGates'
    }

    def __init__(self, cs_pumps=None, cs_valves=None, river_pumps=None, river_gates=None, local_vars_configuration=None):  # noqa: E501
        """ControlRuleInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cs_pumps = None
        self._cs_valves = None
        self._river_pumps = None
        self._river_gates = None
        self.discriminator = None

        self.cs_pumps = cs_pumps
        self.cs_valves = cs_valves
        self.river_pumps = river_pumps
        self.river_gates = river_gates

    @property
    def cs_pumps(self):
        """Gets the cs_pumps of this ControlRuleInfo.  # noqa: E501

        管网泵站调度规则数据  # noqa: E501

        :return: The cs_pumps of this ControlRuleInfo.  # noqa: E501
        :rtype: list[CsPump]
        """
        return self._cs_pumps

    @cs_pumps.setter
    def cs_pumps(self, cs_pumps):
        """Sets the cs_pumps of this ControlRuleInfo.

        管网泵站调度规则数据  # noqa: E501

        :param cs_pumps: The cs_pumps of this ControlRuleInfo.  # noqa: E501
        :type: list[CsPump]
        """

        self._cs_pumps = cs_pumps

    @property
    def cs_valves(self):
        """Gets the cs_valves of this ControlRuleInfo.  # noqa: E501

        管网阀门调度规则数据  # noqa: E501

        :return: The cs_valves of this ControlRuleInfo.  # noqa: E501
        :rtype: list[CsValve]
        """
        return self._cs_valves

    @cs_valves.setter
    def cs_valves(self, cs_valves):
        """Sets the cs_valves of this ControlRuleInfo.

        管网阀门调度规则数据  # noqa: E501

        :param cs_valves: The cs_valves of this ControlRuleInfo.  # noqa: E501
        :type: list[CsValve]
        """

        self._cs_valves = cs_valves

    @property
    def river_pumps(self):
        """Gets the river_pumps of this ControlRuleInfo.  # noqa: E501

        河道泵站调度规则数据  # noqa: E501

        :return: The river_pumps of this ControlRuleInfo.  # noqa: E501
        :rtype: list[RiverPump]
        """
        return self._river_pumps

    @river_pumps.setter
    def river_pumps(self, river_pumps):
        """Sets the river_pumps of this ControlRuleInfo.

        河道泵站调度规则数据  # noqa: E501

        :param river_pumps: The river_pumps of this ControlRuleInfo.  # noqa: E501
        :type: list[RiverPump]
        """

        self._river_pumps = river_pumps

    @property
    def river_gates(self):
        """Gets the river_gates of this ControlRuleInfo.  # noqa: E501

        河道闸门调度规则数据  # noqa: E501

        :return: The river_gates of this ControlRuleInfo.  # noqa: E501
        :rtype: list[RiverGate]
        """
        return self._river_gates

    @river_gates.setter
    def river_gates(self, river_gates):
        """Sets the river_gates of this ControlRuleInfo.

        河道闸门调度规则数据  # noqa: E501

        :param river_gates: The river_gates of this ControlRuleInfo.  # noqa: E501
        :type: list[RiverGate]
        """

        self._river_gates = river_gates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ControlRuleInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ControlRuleInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class CoordinateSequence(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'dimension': 'int',
        'measures': 'int',
        'spatial': 'int',
        'ordinates': 'int',
        'has_z': 'bool',
        'has_m': 'bool',
        'z_ordinate_index': 'int',
        'm_ordinate_index': 'int',
        'first': 'Coordinate',
        'last': 'Coordinate',
        'count': 'int'
    }

    attribute_map = {
        'dimension': 'dimension',
        'measures': 'measures',
        'spatial': 'spatial',
        'ordinates': 'ordinates',
        'has_z': 'hasZ',
        'has_m': 'hasM',
        'z_ordinate_index': 'zOrdinateIndex',
        'm_ordinate_index': 'mOrdinateIndex',
        'first': 'first',
        'last': 'last',
        'count': 'count'
    }

    def __init__(self, dimension=None, measures=None, spatial=None, ordinates=None, has_z=None, has_m=None, z_ordinate_index=None, m_ordinate_index=None, first=None, last=None, count=None, local_vars_configuration=None):  # noqa: E501
        """CoordinateSequence - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._dimension = None
        self._measures = None
        self._spatial = None
        self._ordinates = None
        self._has_z = None
        self._has_m = None
        self._z_ordinate_index = None
        self._m_ordinate_index = None
        self._first = None
        self._last = None
        self._count = None
        self.discriminator = None

        if dimension is not None:
            self.dimension = dimension
        if measures is not None:
            self.measures = measures
        if spatial is not None:
            self.spatial = spatial
        if ordinates is not None:
            self.ordinates = ordinates
        if has_z is not None:
            self.has_z = has_z
        if has_m is not None:
            self.has_m = has_m
        if z_ordinate_index is not None:
            self.z_ordinate_index = z_ordinate_index
        if m_ordinate_index is not None:
            self.m_ordinate_index = m_ordinate_index
        if first is not None:
            self.first = first
        if last is not None:
            self.last = last
        if count is not None:
            self.count = count

    @property
    def dimension(self):
        """Gets the dimension of this CoordinateSequence.  # noqa: E501


        :return: The dimension of this CoordinateSequence.  # noqa: E501
        :rtype: int
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """Sets the dimension of this CoordinateSequence.


        :param dimension: The dimension of this CoordinateSequence.  # noqa: E501
        :type: int
        """

        self._dimension = dimension

    @property
    def measures(self):
        """Gets the measures of this CoordinateSequence.  # noqa: E501


        :return: The measures of this CoordinateSequence.  # noqa: E501
        :rtype: int
        """
        return self._measures

    @measures.setter
    def measures(self, measures):
        """Sets the measures of this CoordinateSequence.


        :param measures: The measures of this CoordinateSequence.  # noqa: E501
        :type: int
        """

        self._measures = measures

    @property
    def spatial(self):
        """Gets the spatial of this CoordinateSequence.  # noqa: E501


        :return: The spatial of this CoordinateSequence.  # noqa: E501
        :rtype: int
        """
        return self._spatial

    @spatial.setter
    def spatial(self, spatial):
        """Sets the spatial of this CoordinateSequence.


        :param spatial: The spatial of this CoordinateSequence.  # noqa: E501
        :type: int
        """

        self._spatial = spatial

    @property
    def ordinates(self):
        """Gets the ordinates of this CoordinateSequence.  # noqa: E501

        0-None 1-X 1-Spatial1 2-Y 2-Spatial2 3-XY 4-Spatial3 4-Z 7-XYZ 8-Spatial4 16-Spatial5 32-Spatial6 64-Spatial7 128-Spatial8 256-Spatial9 512-Spatial10 1024-Spatial11 2048-Spatial12 4096-Spatial13 8192-Spatial14 16384-Spatial15 32768-Spatial16 65535-AllSpatialOrdinates 65536-Measure1 65536-M 65539-XYM 65543-XYZM 131072-Measure2 262144-Measure3 524288-Measure4 1048576-Measure5 2097152-Measure6 4194304-Measure7 8388608-Measure8 16777216-Measure9 33554432-Measure10 67108864-Measure11 134217728-Measure12 268435456-Measure13 536870912-Measure14 1073741824-Measure15 -2147483648-Measure16 -65536-AllMeasureOrdinates -1-AllOrdinates   # noqa: E501

        :return: The ordinates of this CoordinateSequence.  # noqa: E501
        :rtype: int
        """
        return self._ordinates

    @ordinates.setter
    def ordinates(self, ordinates):
        """Sets the ordinates of this CoordinateSequence.

        0-None 1-X 1-Spatial1 2-Y 2-Spatial2 3-XY 4-Spatial3 4-Z 7-XYZ 8-Spatial4 16-Spatial5 32-Spatial6 64-Spatial7 128-Spatial8 256-Spatial9 512-Spatial10 1024-Spatial11 2048-Spatial12 4096-Spatial13 8192-Spatial14 16384-Spatial15 32768-Spatial16 65535-AllSpatialOrdinates 65536-Measure1 65536-M 65539-XYM 65543-XYZM 131072-Measure2 262144-Measure3 524288-Measure4 1048576-Measure5 2097152-Measure6 4194304-Measure7 8388608-Measure8 16777216-Measure9 33554432-Measure10 67108864-Measure11 134217728-Measure12 268435456-Measure13 536870912-Measure14 1073741824-Measure15 -2147483648-Measure16 -65536-AllMeasureOrdinates -1-AllOrdinates   # noqa: E501

        :param ordinates: The ordinates of this CoordinateSequence.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4, 7, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768, 65535, 65536, 65539, 65543, 131072, 262144, 524288, 1048576, 2097152, 4194304, 8388608, 16777216, 33554432, 67108864, 134217728, 268435456, 536870912, 1073741824, -2147483648, -65536, -1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ordinates not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `ordinates` ({0}), must be one of {1}"  # noqa: E501
                .format(ordinates, allowed_values)
            )

        self._ordinates = ordinates

    @property
    def has_z(self):
        """Gets the has_z of this CoordinateSequence.  # noqa: E501


        :return: The has_z of this CoordinateSequence.  # noqa: E501
        :rtype: bool
        """
        return self._has_z

    @has_z.setter
    def has_z(self, has_z):
        """Sets the has_z of this CoordinateSequence.


        :param has_z: The has_z of this CoordinateSequence.  # noqa: E501
        :type: bool
        """

        self._has_z = has_z

    @property
    def has_m(self):
        """Gets the has_m of this CoordinateSequence.  # noqa: E501


        :return: The has_m of this CoordinateSequence.  # noqa: E501
        :rtype: bool
        """
        return self._has_m

    @has_m.setter
    def has_m(self, has_m):
        """Sets the has_m of this CoordinateSequence.


        :param has_m: The has_m of this CoordinateSequence.  # noqa: E501
        :type: bool
        """

        self._has_m = has_m

    @property
    def z_ordinate_index(self):
        """Gets the z_ordinate_index of this CoordinateSequence.  # noqa: E501


        :return: The z_ordinate_index of this CoordinateSequence.  # noqa: E501
        :rtype: int
        """
        return self._z_ordinate_index

    @z_ordinate_index.setter
    def z_ordinate_index(self, z_ordinate_index):
        """Sets the z_ordinate_index of this CoordinateSequence.


        :param z_ordinate_index: The z_ordinate_index of this CoordinateSequence.  # noqa: E501
        :type: int
        """

        self._z_ordinate_index = z_ordinate_index

    @property
    def m_ordinate_index(self):
        """Gets the m_ordinate_index of this CoordinateSequence.  # noqa: E501


        :return: The m_ordinate_index of this CoordinateSequence.  # noqa: E501
        :rtype: int
        """
        return self._m_ordinate_index

    @m_ordinate_index.setter
    def m_ordinate_index(self, m_ordinate_index):
        """Sets the m_ordinate_index of this CoordinateSequence.


        :param m_ordinate_index: The m_ordinate_index of this CoordinateSequence.  # noqa: E501
        :type: int
        """

        self._m_ordinate_index = m_ordinate_index

    @property
    def first(self):
        """Gets the first of this CoordinateSequence.  # noqa: E501


        :return: The first of this CoordinateSequence.  # noqa: E501
        :rtype: Coordinate
        """
        return self._first

    @first.setter
    def first(self, first):
        """Sets the first of this CoordinateSequence.


        :param first: The first of this CoordinateSequence.  # noqa: E501
        :type: Coordinate
        """

        self._first = first

    @property
    def last(self):
        """Gets the last of this CoordinateSequence.  # noqa: E501


        :return: The last of this CoordinateSequence.  # noqa: E501
        :rtype: Coordinate
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this CoordinateSequence.


        :param last: The last of this CoordinateSequence.  # noqa: E501
        :type: Coordinate
        """

        self._last = last

    @property
    def count(self):
        """Gets the count of this CoordinateSequence.  # noqa: E501


        :return: The count of this CoordinateSequence.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this CoordinateSequence.


        :param count: The count of this CoordinateSequence.  # noqa: E501
        :type: int
        """

        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CoordinateSequence):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CoordinateSequence):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    scenario-compute-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_scenario_compute_service.configuration import Configuration


class DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'schedule_scenario_id': 'str',
        'flood_storage_area_id': 'str',
        'name': 'str',
        'initial_wl': 'float',
        'description': 'str'
    }

    attribute_map = {
        'schedule_scenario_id': 'scheduleScenarioId',
        'flood_storage_area_id': 'floodStorageAreaId',
        'name': 'name',
        'initial_wl': 'initialWL',
        'description': 'description'
    }

    def __init__(self, schedule_scenario_id=None, flood_storage_area_id=None, name=None, initial_wl=None, description=None, local_vars_configuration=None):  # noqa: E501
        """DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._schedule_scenario_id = None
        self._flood_storage_area_id = None
        self._name = None
        self._initial_wl = None
        self._description = None
        self.discriminator = None

        if schedule_scenario_id is not None:
            self.schedule_scenario_id = schedule_scenario_id
        if flood_storage_area_id is not None:
            self.flood_storage_area_id = flood_storage_area_id
        self.name = name
        if initial_wl is not None:
            self.initial_wl = initial_wl
        self.description = description

    @property
    def schedule_scenario_id(self):
        """Gets the schedule_scenario_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501

        River flood schedule scenario id  # noqa: E501

        :return: The schedule_scenario_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :rtype: str
        """
        return self._schedule_scenario_id

    @schedule_scenario_id.setter
    def schedule_scenario_id(self, schedule_scenario_id):
        """Sets the schedule_scenario_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.

        River flood schedule scenario id  # noqa: E501

        :param schedule_scenario_id: The schedule_scenario_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :type: str
        """

        self._schedule_scenario_id = schedule_scenario_id

    @property
    def flood_storage_area_id(self):
        """Gets the flood_storage_area_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501

        Flood storage area id  # noqa: E501

        :return: The flood_storage_area_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :rtype: str
        """
        return self._flood_storage_area_id

    @flood_storage_area_id.setter
    def flood_storage_area_id(self, flood_storage_area_id):
        """Sets the flood_storage_area_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.

        Flood storage area id  # noqa: E501

        :param flood_storage_area_id: The flood_storage_area_id of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :type: str
        """

        self._flood_storage_area_id = flood_storage_area_id

    @property
    def name(self):
        """Gets the name of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501

        Scenario name  # noqa: E501

        :return: The name of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.

        Scenario name  # noqa: E501

        :param name: The name of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def initial_wl(self):
        """Gets the initial_wl of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501

        Initial water level of the flood storage area  # noqa: E501

        :return: The initial_wl of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :rtype: float
        """
        return self._initial_wl

    @initial_wl.setter
    def initial_wl(self, initial_wl):
        """Sets the initial_wl of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.

        Initial water level of the flood storage area  # noqa: E501

        :param initial_wl: The initial_wl of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :type: float
        """

        self._initial_wl = initial_wl

    @property
    def description(self):
        """Gets the description of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501

        Scenario description  # noqa: E501

        :return: The description of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.

        Scenario description  # noqa: E501

        :param description: The description of this DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DhiDssScenarioComputeRfDtosCreateFloodStorageAreaScenarioInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class UpdatePumpDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'muid': 'str',
        'from_node': 'str',
        'to_node': 'str',
        'pump_type': 'int',
        'speed': 'float',
        'pattern_id': 'str',
        'constant_power': 'float',
        'zone_id': 'str',
        'description': 'str',
        'data_source': 'str',
        'asset_name': 'str',
        'from_x': 'float',
        'from_y': 'float',
        'to_x': 'float',
        'to_y': 'float',
        'id': 'str'
    }

    attribute_map = {
        'muid': 'muid',
        'from_node': 'fromNode',
        'to_node': 'toNode',
        'pump_type': 'pumpType',
        'speed': 'speed',
        'pattern_id': 'patternID',
        'constant_power': 'constantPower',
        'zone_id': 'zoneID',
        'description': 'description',
        'data_source': 'dataSource',
        'asset_name': 'assetName',
        'from_x': 'fromX',
        'from_y': 'fromY',
        'to_x': 'toX',
        'to_y': 'toY',
        'id': 'id'
    }

    def __init__(self, muid=None, from_node=None, to_node=None, pump_type=None, speed=None, pattern_id=None, constant_power=None, zone_id=None, description=None, data_source=None, asset_name=None, from_x=None, from_y=None, to_x=None, to_y=None, id=None, local_vars_configuration=None):  # noqa: E501
        """UpdatePumpDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._muid = None
        self._from_node = None
        self._to_node = None
        self._pump_type = None
        self._speed = None
        self._pattern_id = None
        self._constant_power = None
        self._zone_id = None
        self._description = None
        self._data_source = None
        self._asset_name = None
        self._from_x = None
        self._from_y = None
        self._to_x = None
        self._to_y = None
        self._id = None
        self.discriminator = None

        self.muid = muid
        self.from_node = from_node
        self.to_node = to_node
        if pump_type is not None:
            self.pump_type = pump_type
        if speed is not None:
            self.speed = speed
        self.pattern_id = pattern_id
        if constant_power is not None:
            self.constant_power = constant_power
        self.zone_id = zone_id
        self.description = description
        self.data_source = data_source
        self.asset_name = asset_name
        if from_x is not None:
            self.from_x = from_x
        if from_y is not None:
            self.from_y = from_y
        if to_x is not None:
            self.to_x = to_x
        if to_y is not None:
            self.to_y = to_y
        if id is not None:
            self.id = id

    @property
    def muid(self):
        """Gets the muid of this UpdatePumpDto.  # noqa: E501

        模型中泵站ID pump muid  # noqa: E501

        :return: The muid of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._muid

    @muid.setter
    def muid(self, muid):
        """Sets the muid of this UpdatePumpDto.

        模型中泵站ID pump muid  # noqa: E501

        :param muid: The muid of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._muid = muid

    @property
    def from_node(self):
        """Gets the from_node of this UpdatePumpDto.  # noqa: E501

        起始节点 from node  # noqa: E501

        :return: The from_node of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._from_node

    @from_node.setter
    def from_node(self, from_node):
        """Sets the from_node of this UpdatePumpDto.

        起始节点 from node  # noqa: E501

        :param from_node: The from_node of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._from_node = from_node

    @property
    def to_node(self):
        """Gets the to_node of this UpdatePumpDto.  # noqa: E501

        终止节点 to node  # noqa: E501

        :return: The to_node of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._to_node

    @to_node.setter
    def to_node(self, to_node):
        """Sets the to_node of this UpdatePumpDto.

        终止节点 to node  # noqa: E501

        :param to_node: The to_node of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._to_node = to_node

    @property
    def pump_type(self):
        """Gets the pump_type of this UpdatePumpDto.  # noqa: E501

        泵站类型 pump type  # noqa: E501

        :return: The pump_type of this UpdatePumpDto.  # noqa: E501
        :rtype: int
        """
        return self._pump_type

    @pump_type.setter
    def pump_type(self, pump_type):
        """Sets the pump_type of this UpdatePumpDto.

        泵站类型 pump type  # noqa: E501

        :param pump_type: The pump_type of this UpdatePumpDto.  # noqa: E501
        :type: int
        """

        self._pump_type = pump_type

    @property
    def speed(self):
        """Gets the speed of this UpdatePumpDto.  # noqa: E501

        泵站速度 pump speed  # noqa: E501

        :return: The speed of this UpdatePumpDto.  # noqa: E501
        :rtype: float
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this UpdatePumpDto.

        泵站速度 pump speed  # noqa: E501

        :param speed: The speed of this UpdatePumpDto.  # noqa: E501
        :type: float
        """

        self._speed = speed

    @property
    def pattern_id(self):
        """Gets the pattern_id of this UpdatePumpDto.  # noqa: E501

        模式ID pattern id  # noqa: E501

        :return: The pattern_id of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._pattern_id

    @pattern_id.setter
    def pattern_id(self, pattern_id):
        """Sets the pattern_id of this UpdatePumpDto.

        模式ID pattern id  # noqa: E501

        :param pattern_id: The pattern_id of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._pattern_id = pattern_id

    @property
    def constant_power(self):
        """Gets the constant_power of this UpdatePumpDto.  # noqa: E501

        泵站功率 pump constant power  # noqa: E501

        :return: The constant_power of this UpdatePumpDto.  # noqa: E501
        :rtype: float
        """
        return self._constant_power

    @constant_power.setter
    def constant_power(self, constant_power):
        """Sets the constant_power of this UpdatePumpDto.

        泵站功率 pump constant power  # noqa: E501

        :param constant_power: The constant_power of this UpdatePumpDto.  # noqa: E501
        :type: float
        """

        self._constant_power = constant_power

    @property
    def zone_id(self):
        """Gets the zone_id of this UpdatePumpDto.  # noqa: E501

        分区ID zone id  # noqa: E501

        :return: The zone_id of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this UpdatePumpDto.

        分区ID zone id  # noqa: E501

        :param zone_id: The zone_id of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    @property
    def description(self):
        """Gets the description of this UpdatePumpDto.  # noqa: E501

        描述 description  # noqa: E501

        :return: The description of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdatePumpDto.

        描述 description  # noqa: E501

        :param description: The description of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def data_source(self):
        """Gets the data_source of this UpdatePumpDto.  # noqa: E501

        数据源 data source  # noqa: E501

        :return: The data_source of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this UpdatePumpDto.

        数据源 data source  # noqa: E501

        :param data_source: The data_source of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._data_source = data_source

    @property
    def asset_name(self):
        """Gets the asset_name of this UpdatePumpDto.  # noqa: E501

        资产名称 asset name  # noqa: E501

        :return: The asset_name of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._asset_name

    @asset_name.setter
    def asset_name(self, asset_name):
        """Sets the asset_name of this UpdatePumpDto.

        资产名称 asset name  # noqa: E501

        :param asset_name: The asset_name of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._asset_name = asset_name

    @property
    def from_x(self):
        """Gets the from_x of this UpdatePumpDto.  # noqa: E501

        起始节点坐标X coordinate x of from-node  # noqa: E501

        :return: The from_x of this UpdatePumpDto.  # noqa: E501
        :rtype: float
        """
        return self._from_x

    @from_x.setter
    def from_x(self, from_x):
        """Sets the from_x of this UpdatePumpDto.

        起始节点坐标X coordinate x of from-node  # noqa: E501

        :param from_x: The from_x of this UpdatePumpDto.  # noqa: E501
        :type: float
        """

        self._from_x = from_x

    @property
    def from_y(self):
        """Gets the from_y of this UpdatePumpDto.  # noqa: E501

        起始节点坐标Y coordinate y of from-node  # noqa: E501

        :return: The from_y of this UpdatePumpDto.  # noqa: E501
        :rtype: float
        """
        return self._from_y

    @from_y.setter
    def from_y(self, from_y):
        """Sets the from_y of this UpdatePumpDto.

        起始节点坐标Y coordinate y of from-node  # noqa: E501

        :param from_y: The from_y of this UpdatePumpDto.  # noqa: E501
        :type: float
        """

        self._from_y = from_y

    @property
    def to_x(self):
        """Gets the to_x of this UpdatePumpDto.  # noqa: E501

        终止节点坐标X coordinate x of to-node  # noqa: E501

        :return: The to_x of this UpdatePumpDto.  # noqa: E501
        :rtype: float
        """
        return self._to_x

    @to_x.setter
    def to_x(self, to_x):
        """Sets the to_x of this UpdatePumpDto.

        终止节点坐标X coordinate x of to-node  # noqa: E501

        :param to_x: The to_x of this UpdatePumpDto.  # noqa: E501
        :type: float
        """

        self._to_x = to_x

    @property
    def to_y(self):
        """Gets the to_y of this UpdatePumpDto.  # noqa: E501

        终止节点坐标Y coordinate y of to-node  # noqa: E501

        :return: The to_y of this UpdatePumpDto.  # noqa: E501
        :rtype: float
        """
        return self._to_y

    @to_y.setter
    def to_y(self, to_y):
        """Sets the to_y of this UpdatePumpDto.

        终止节点坐标Y coordinate y of to-node  # noqa: E501

        :param to_y: The to_y of this UpdatePumpDto.  # noqa: E501
        :type: float
        """

        self._to_y = to_y

    @property
    def id(self):
        """Gets the id of this UpdatePumpDto.  # noqa: E501

        泵站ID pump id  # noqa: E501

        :return: The id of this UpdatePumpDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdatePumpDto.

        泵站ID pump id  # noqa: E501

        :param id: The id of this UpdatePumpDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePumpDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdatePumpDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class DataCleanTagConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'tag': 'str',
        'status': 'str',
        'message': 'str',
        'health': 'bool',
        'label': 'str',
        'default': 'bool',
        'grade': 'int'
    }

    attribute_map = {
        'id': 'id',
        'tag': 'tag',
        'status': 'status',
        'message': 'message',
        'health': 'health',
        'label': 'label',
        'default': 'default',
        'grade': 'grade'
    }

    def __init__(self, id=None, tag=None, status=None, message=None, health=None, label=None, default=None, grade=None, local_vars_configuration=None):  # noqa: E501
        """DataCleanTagConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._tag = None
        self._status = None
        self._message = None
        self._health = None
        self._label = None
        self._default = None
        self._grade = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.tag = tag
        self.status = status
        self.message = message
        if health is not None:
            self.health = health
        self.label = label
        if default is not None:
            self.default = default
        if grade is not None:
            self.grade = grade

    @property
    def id(self):
        """Gets the id of this DataCleanTagConfigOutput.  # noqa: E501

        配置ID config id  # noqa: E501

        :return: The id of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DataCleanTagConfigOutput.

        配置ID config id  # noqa: E501

        :param id: The id of this DataCleanTagConfigOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def tag(self):
        """Gets the tag of this DataCleanTagConfigOutput.  # noqa: E501

        标签 data clean tag  # noqa: E501

        :return: The tag of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this DataCleanTagConfigOutput.

        标签 data clean tag  # noqa: E501

        :param tag: The tag of this DataCleanTagConfigOutput.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def status(self):
        """Gets the status of this DataCleanTagConfigOutput.  # noqa: E501

        状态信息 device status  # noqa: E501

        :return: The status of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DataCleanTagConfigOutput.

        状态信息 device status  # noqa: E501

        :param status: The status of this DataCleanTagConfigOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """Gets the message of this DataCleanTagConfigOutput.  # noqa: E501

        维护预警 device maintenance  # noqa: E501

        :return: The message of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DataCleanTagConfigOutput.

        维护预警 device maintenance  # noqa: E501

        :param message: The message of this DataCleanTagConfigOutput.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def health(self):
        """Gets the health of this DataCleanTagConfigOutput.  # noqa: E501

        是否正常 if the device is health  # noqa: E501

        :return: The health of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: bool
        """
        return self._health

    @health.setter
    def health(self, health):
        """Sets the health of this DataCleanTagConfigOutput.

        是否正常 if the device is health  # noqa: E501

        :param health: The health of this DataCleanTagConfigOutput.  # noqa: E501
        :type: bool
        """

        self._health = health

    @property
    def label(self):
        """Gets the label of this DataCleanTagConfigOutput.  # noqa: E501

        状态标识 status label  # noqa: E501

        :return: The label of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this DataCleanTagConfigOutput.

        状态标识 status label  # noqa: E501

        :param label: The label of this DataCleanTagConfigOutput.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def default(self):
        """Gets the default of this DataCleanTagConfigOutput.  # noqa: E501

        是否默认 if it is a default tag  # noqa: E501

        :return: The default of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this DataCleanTagConfigOutput.

        是否默认 if it is a default tag  # noqa: E501

        :param default: The default of this DataCleanTagConfigOutput.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def grade(self):
        """Gets the grade of this DataCleanTagConfigOutput.  # noqa: E501


        :return: The grade of this DataCleanTagConfigOutput.  # noqa: E501
        :rtype: int
        """
        return self._grade

    @grade.setter
    def grade(self, grade):
        """Sets the grade of this DataCleanTagConfigOutput.


        :param grade: The grade of this DataCleanTagConfigOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and grade not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `grade` ({0}), must be one of {1}"  # noqa: E501
                .format(grade, allowed_values)
            )

        self._grade = grade

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataCleanTagConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataCleanTagConfigOutput):
            return True

        return self.to_dict() != other.to_dict()
